// This is a simple example
package main

import (
	"os"

	"go.wit.com/log"

	"go.wit.com/gui"
	"go.wit.com/lib/gadgets"
	"go.wit.com/lib/gui/repostatus"
)

func doesExist(path string) bool {
	if _, err := os.Stat(path); err != nil {
		if os.IsNotExist(err) {
			return false
		}
	}
	return true
}

// only errors on bad errors
func quickCmd(fullpath string, cmd []string) bool {
	var err error
	var b bool
	var output string

	if me.autoWorkingPwd.String() != fullpath {
		me.autoWorkingPwd.SetValue(fullpath)
	}
	log.Warn("RUN:", fullpath, cmd)
	if me.autoDryRun.Checked() {
		return false
	}

	err, b, output = repostatus.RunCmd(fullpath, cmd)
	if err != nil {
		log.Error(err)
		return false
	} else if !b {
		log.Warn("b =", b)
		log.Warn("output =", string(output))
		return true
	}
	log.Warn("output = ", string(output))
	return true
}

func globalBuildOptions(box *gui.Node) {
	vbox := box.NewVerticalBox("DISPLAYVBOX")
	group1 := vbox.NewGroup("Global Build Options")
	grid := group1.NewGrid("buildOptions", 2, 1)

	me.mainBranch = gadgets.NewBasicCombobox(grid, "default main branch")
	me.mainBranch.AddText("gitea server default")
	me.mainBranch.Disable()

	me.develBranch = gadgets.NewBasicCombobox(grid, "default devel branch")
	me.develBranch.AddText("devel")

	me.userBranch = gadgets.NewBasicCombobox(grid, "default user branch")
	me.userBranch.AddText("jcarr")

	grid.NewLabel("<nil>")
	grid.NewButton("set working branches", func() {
		log.Warn("set working branches here")
	})
	// gadgets.OneLiner(grid, "default user branch")

	// select the branch you want to test, build and develop against
	// this lets you select your user branch, but, when you are happy
	// you can merge everything into the devel branch and make sure it actually
	// works. Then, when that is good, merge and version everything in master
	var newBranch *gui.Node
	grid.NewButton("set current branch to:", func() {
		log.Warn("set current branch to:", newBranch.String())
		/*
			me.toMoveToBranch = guiBranch.String()
			setCurrentBranch.SetLabel("set all branches to " + me.toMoveToBranch)
			me.mainBranch.Disable()
		*/
	})
	newBranch = grid.NewCombobox()
	newBranch.AddText("guimaster")
	newBranch.AddText("master")
	newBranch.AddText("main")
	newBranch.AddText("guidevel")
	newBranch.AddText("jcarr")
	newBranch.SetText("jcarr")

	me.autoWorkingPwd = gadgets.NewOneLiner(grid, "working directory (pwd)")

	group2 := vbox.NewGroup("Run in every git repository")
	me.stopOnErrors = group2.NewCheckbox("Stop on errors")
	me.stopOnErrors.SetChecked(true)

	me.autoDryRun = group2.NewCheckbox("autotypist --dry-run")
	me.autoDryRun.SetChecked(true)

	group2.NewButton("parse .git/config ScanGitConfig()", func() {
		repostatus.ScanGitConfig()
	})

	group2.NewButton("parse go.sum ScanGoSrc()", func() {
		repostatus.ScanGoSrc()
	})

	group2.NewButton("run git status", func() {
		me.autoWorkingPwd.SetValue("~/go/src")
		log.Warn("scanning allrepos")
		for path, _ := range me.allrepos {
			fullpath := "/home/jcarr/go/src/" + path
			quickCmd(fullpath, []string{"git", "status"})
		}
	})

	me.rerunGoMod = group2.NewButton("remove go.mod & go.sum", func() {
		for path, _ := range me.allrepos {
			fullpath := "/home/jcarr/go/src/" + path
			if quickCmd(fullpath, []string{"rm", "-f", "go.mod", "go.sum"}) {
				log.Info("rm go.mod FAILED in repo", fullpath, me.stopOnErrors.Bool())
				if me.stopOnErrors.Bool() {
					return
				}
			}
		}
	})

	me.rerunGoMod = group2.NewButton("run go mod & go tidy", func() {
		os.Unsetenv("GO111MODULE")
		for path, _ := range me.allrepos {
			fullpath := "/home/jcarr/go/src/" + path
			quickCmd(fullpath, []string{"go", "mod", "init"})
			quickCmd(fullpath, []string{"go", "mod", "tidy"})
		}
	})

	me.rerunGoMod = group2.NewButton("git checkout go.mod & go.sum", func() {
		for path, _ := range me.allrepos {
			fullpath := "/home/jcarr/go/src/" + path
			quickCmd(fullpath, []string{"git", "checkout", "go.mod"})
			quickCmd(fullpath, []string{"git", "checkout", "go.sum"})
		}
	})
}
